# Scenario Input Parameters Descriptions

| **Scenario Input Parameter**                                                                                                                                                                                                                   | **Description**                                                                                                                                                                                                                                                                                                                                                                                    | **Data Type(s) Accepted** |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------|
| selection                                                                                                                                                                                                                               | Selection number that is used to match with the corresponding vehicles on the Demo_FY22_vehicle_assumptions.csv file                                                                                                                                                                                                                                                                           | int                   |
| scenario_name                                                                                                                                                                                                                           | Name of the vehicle and scenario - Includes names                                                                                                                                                                                                                                                                                                                                              | string                |
| veh_year                                                                                                                                                                                                                                | Current year                                                                                                                                                                                                                                                                                                                                                                                   | int                   |
| drive_cycle                                                                                                                                                                                                                             | Relative filepath of drivecycle input file(s)  from /t3co/resources/cycles/ folder - accepts single drivecyle path, composite cycles (for example: '[("EPA_Ph2_rural_interstate_65mph.csv", .86), ("EPA_Ph2_urban_highway_55mph.csv", .09), ("EPA_Ph2_transient.csv", .05)]'), or path to folder containing multiple drivecycles (results in corresponding number of scenarios) | string                |
| vmt_reduct_per_yr                                                                                                                                                                                                                       | not used                                                                                                                                                                                                                                                                                                                                                                                       |                       |
| vmt                                                                                                                                                                                                                                     | Vehicle Miles Traveled as an array/list with length>=vehicle_life_yr                                                                                                                                                                                                                                                                                                                           | list\[int\]                  |
| constant_trip_distance_mi                                                                                                                                                                                                               | not used                                                                                                                                                                                                                                                                                                                                                                                       |                       |
| vehicle_life_yr                                                                                                                                                                                                                         | Number of years to calculate TCO for - generally the expected life of the vehicle in years                                                                                                                                                                                                                                                                                                     | int                   |
| desired_ess_replacements                                                                                                                                                                                                                | not used                                                                                                                                                                                                                                                                                                                                                                                       |                       |
| discount_rate_pct_per_yr                                                                                                                                                                                                                | Discount rate per year as a fraction/year to account for time value of money and alternative investment opportunities. This is applied as a constant rate for TCO cost components                                                                                                                                                                                                              | float                 |
| ess_max_charging_power_kw                                                                                                                                                                                                               | Maximum charging power available in kW (infrastructure dependent) for ESS (Energy Storage Systems like Li-ion battery packs) in xEVs                                                                                                                                                                                                                                                           | float                 |
| ess_cost_dol_per_kw                                                                                                                                                                                                                     | not used                                                                                                                                                                                                                                                                                                                                                                                       |                       |
| ess_cost_dol_per_kwh                                                                                                                                                                                                                    | Cost of ESS in dollars per kWh of capacity                                                                                                                                                                                                                                                                                                                                                     | float                 |
| ess_base_cost_dol                                                                                                                                                                                                                       | Cost of ESSs packaging in dollars that is added to vehicle.ess_max_kwh * scenario.ess_cost_dol_per_kwh to estimate total ESS cost                                                                                                                                                                                                                                                              | float                 |
| ess_cost_reduction_dol_per_yr                                                                                                                                                                                                           | Reduction of ESS cost per year - not used                                                                                                                                                                                                                                                                                                                                                      | float                 |
| ess_salvage_value_dol                                                                                                                                                                                                                   | Salvage Value of ESS at end of vehicle_life_yr - not used                                                                                                                                                                                                                                                                                                                                      | float                 |
| pe_mc_cost_dol_per_kw                                                                                                                                                                                                                   | Cost of Power Electronics and Motor Controllers in dollars per kW                                                                                                                                                                                                                                                                                                                              | float                 |
| pe_mc_base_cost_dol                                                                                                                                                                                                                     | Cost of Power Electronics and Motor Controllers baseline that is added to vehicle.mc_max_kw * scenario.pe_mc_cost_dol_per_kw to estimate total PE&MC cost                                                                                                                                                                                                                                      | float                 |
fc_ice_cost_dol_per_kw                                                                                                                                                                                                                  | Cost of Internal Combustion Engine per kW of power for Conventional vehicles     |                                                                                                                                                                                                                                                                                                                float |
fc_ice_base_cost_dol                                   | Cost of Fuel Convertor baseline that is added to vehicle.fc_max_kw \* scenario.fc_ice_cost_dol_per_kw to estimate total FC cost baseline that is added to vehicle.fc_max_kw \* scenario.fc_ice_cost_dol_per_kw to estimate total FC cost" | float                                                                                                                                                                                                                                                                                                                                                                                          |                       |
| fc_fuelcell_cost_dol_per_kw                                                                                                                                                                                                             | Cost of Hydrogen fuel cells per kW of power for FCEVs                                                                                                                                                                                                                                                                                                                                          | float                 |
| fs_cost_dol_per_kwh                                                                                                                                                                                                                     | Cost of liquid fuel storage tanks per kWh of capacity for liquid fuel like diesel/gasoline                                                                                                                                                                                                                                                                                                     | float                 |
| fs_h2_cost_dol_per_kwh                                                                                                                                                                                                                  | Cost of gas fuel storage tanks per kWh of capacity for gaseous fuel like hydrogen                                                                                                                                                                                                                                                                                                              | float                 |
| fs_fueling_rate_kg_per_min                                                                                                                                                                                                              | Fill rate in kg per min (KPM) for gaseous fuels like hydrogen, propane - infrastructure dependent                                                                                                                                                                                                                                                                                              | float                 |
| fs_fueling_rate_gasoline_gpm                                                                                                                                                                                                            | Fill rate in gallons per min (GPM) for gasoline - infrastructure dependent                                                                                                                                                                                                                                                                                                                     | float                 |
| fs_fueling_rate_diesel_gpm                                                                                                                                                                                                              | Fill rate in gallons per min (GPM) for diesel - infrastructure dependent                                                                                                                                                                                                                                                                                                                       | float                 |
| plug_base_cost_dol                                                                                                                                                                                                                      | Cost of plugin connections on  certain xEVs                                                                                                                                                                                                                                                                                                                                                    | float                 |
| markup_pct                                                                                                                                                                                                                              | Markup on price of vehicle as percentage of MSRP (eg., 1.20 means 20% markup_pct on MSRP)                                                                                                                                                                                                                                                                                                      | float                 |
| tax_rate_pct                                                                                                                                                                                                                            | Registration and other taxes during time of purchase as percent on the MSRP (eg., 0.125 means 12.5% of MSRP)                                                                                                                                                                                                                                                                                   | float                 |
| fc_cng_ice_cost_dol_per_kw                                                                                                                                                                                                              | Cost of CNG engine per kW of max power                                                                                                                                                                                                                                                                                                                                                         | float                 |
| fs_cng_cost_dol_per_kwh                                                                                                                                                                                                                 | Cost of CNG fuel storage per kWh of max fuel tank capacity                                                                                                                                                                                                                                                                                                                                     | float                 |
| vehicle_glider_cost_dol                                                                                                                                                                                                                 | Cost of glider (vehicle without powertrain) in dollars                                                                                                                                                                                                                                                                                                                                         | float                 |
| segment_name                                                                                                                                                                                                                            | Name of the vehicle type or fleet name                                                                                                                                                                                                                                                                                                                                                         | string                |
| gvwr_kg                                                                                                                                                                                                                                 | Gross Vehicle Weight Rating upper limit  in kg for the vehicle's weight class                                                                                                                                                                                                                                                                                                                  | float                 |
| gvwr_credit_kg                                                                                                                                                                                                                          | Additional allowable weight in kg for advanced vehicles (eg. 2000lb credit for Class 8 BEVs)                                                                                                                                                                                                                                                                                                   | float                 |
| fuel_type                                                                                                                                                                                                                               | Fuel name - should be one of : ['diesel', 'gasoline', 'hydrogen', 'electricity', 'cng']. For hybrids, use the primary fuel                                                                                                                                                                                                                                                                     | string                |
| maint_oper_cost_dol_per_mi                                                                                                                                                                                                              | Vehicle maintenance operating cost in dollars per mile traveled as vector of length equal to number of TCO years                                                                                                                                                                                                                                                                               | list\[float\]                  |
| vocation                                                                                                                                                                                                                                | Vocation of the vehicle - only for user reference                                                                                                                                                                                                                                                                                                                                              | string                |
| model_year                                                                                                                                                                                                                              | Vehicle model year                                                                                                                                                                                                                                                                                                                                                                             | int                   |
| region                                                                                                                                                                                                                                  | Region name is used as a key to find the right fuel prices for the analysis. Refer to /t3co/resources/FuelPrices.csv for region name                                                                                                                                                                                                                                                           | string                |
| target_range_mi                                                                                                                                                                                                                         | Target range in miles to be achieved by the optimized vehicle                                                                                                                                                                                                                                                                                                                                  | float                 |
| min_speed_at_6pct_grade_in_5min_mph                                                                                                                                                                                                     | Minimum speed in miles/hour for the optimized vehicle to attain from 0 mph in 5 mins for a 6 percent gradeability test                                                                                                                                                                                                                                                                         | float                 |
| min_speed_at_1p25pct_grade_in_5min_mph                                                                                                                                                                                                   | Minimum speed in miles/hour for the optimized vehicle to attain from 0 mph in 5 mins for a 1.25 percent gradeability test                                                                                                                                                                                                                                                                      | float                 |
| max_time_0_to_60mph_at_gvwr_s                                                                                                                                                                                                           | Maximum time taken by optimized vehicle (at GVWR weight limit) to accelerate from 0 to 60 mph - acceleration test                                                                                                                                                                                                                                                                              | float                 |
| max_time_0_to_30mph_at_gvwr_s                                                                                                                                                                                                           | Maximum time taken by optimized vehicle (at GVWR weight limit) to accelerate from 0 to 30 mph - acceleration test                                                                                                                                                                                                                                                                              | float                 |
| lw_imp_curve_sel                                                                                                                                                                                                                       | Complete file path to light weighting improvement curve - cost vs weight reduced                                                                                                                                                                                                                                                                                                               | string                |
| eng_eff_imp_curve_sel                                                                                                                                                                                                                  | Complete file path to engine efficiency improvement curve - cost vs efficiency                                                                                                                                                                                                                                                                                                                 | string                |
| aero_drag_imp_curve_sel                                                                                                                                                                                                                | Complete file path to aero drag improvement curve - cost vs drag coefficient                                                                                                                                                                                                                                                                                                                   | string                |
| skip_opt                                                                                                                                                                                                                                | Boolean switch for skipping the optimization module                                                                                                                                                                                                                                                                                                                                            | bool                  |
| knob_min_ess_kwh                                                                                                                                                                                                                        | Optimization bounds - minimum ESS capacity in kWh                                                                                                                                                                                                                                                                                                                                              | float                 |
| knob_max_ess_kwh                                                                                                                                                                                                                        | Optimization bounds - maximum ESS capacity in kWh                                                                                                                                                                                                                                                                                                                                              | float                 |
| knob_min_motor_kw                                                                                                                                                                                                                       | Optimization bounds - minimum motor peak power in kW                                                                                                                                                                                                                                                                                                                                           | float                 |
| knob_max_motor_kw                                                                                                                                                                                                                       | Optimization bounds - maximum motor peak power in kW                                                                                                                                                                                                                                                                                                                                           | float                 |
| knob_min_fc_kw                                                                                                                                                                                                                          | Optimization bounds - minimum fuel convertor peak power in kW                                                                                                                                                                                                                                                                                                                                  | float                 |
| knob_max_fc_kw                                                                                                                                                                                                                          | Optimization bounds - maximum fuel convertor peak power in kW                                                                                                                                                                                                                                                                                                                                  | float                 |
| knob_min_fs_kwh                                                                                                                                                                                                                         | Optimization bounds - minimum fuel storage capacity in kWh                                                                                                                                                                                                                                                                                                                                     | float                 |
| knob_max_fs_kwh                                                                                                                                                                                                                         | Optimization bounds - maximum fuel storage capacity in kWh                                                                                                                                                                                                                                                                                                                                     | float                 |
| constraint_range                                                                                                                                                                                                                        | Optimization constraint - Range                                                                                                                                                                                                                                                                                                                                                                |                       |
| constraint_accel                                                                                                                                                                                                                        | Optimization constraint - Acceleration 0-30mph, Acceleration 0-60mph                                                                                                                                                                                                                                                                                                                           | bool                  |
| constraint_grade                                                                                                                                                                                                                        | Optimization constraint - Gradeability 1.25% grade and 6% grade                                                                                                                                                                                                                                                                                                                                | bool                  |
| objective_tco                                                                                                                                                                                                                           | Boolean switch for minimizing TCO as optimization objective                                                                                                                                                                                                                                                                                                                                    | bool                  |
| constraint_c_rate                                                                                                                                                                                                                       | Optimization constraint - Charge Rate                                                                                                                                                                                                                                                                                                                                                          | bool                  |
| shifts_per_year                                                                                                                                                                                                                         | Number of shifts/drivecycle instances per year traveled by the vehicle as a vector of length equal to number of TCO years. if = 0, then it's calculated from vmt and daily distance                                                                                                                                                                                                            | list\[int\]                  |
| motor_power_override_kw_fc_demand_on_pct                                                                                                                                                                                                | For PHEV, percentage motor power override as fraction                                                                                                                                                                                                                                                                                                                                          | float                 |
| soc_norm_init_for_accel_pct                                                                                                                                                                                                             | Initial normalized SOC for acceleration test (only PHEV)                                                                                                                                                                                                                                                                                                                                       | float                 |
| soc_norm_init_for_grade_pct                                                                                                                                                                                                             | Initial normalized SOC for gradeability test (only PHEV)                                                                                                                                                                                                                                                                                                                                       | float                 |
| labor_rate_dol_per_hr                                                                                                                                                                                                                   | Labor Rate for dollars per hour of vehicle operation                                                                                                                                                                                                                                                                                                                                           | float                 |
| activate_tco_payload_cap_cost_multiplier                                                                                                                                                                                                | Boolean switch to activate lost payload capacity opportunity cost calculation                                                                                                                                                                                                                                                                                                                  | bool                  |
| plf_ref_veh_empty_mass_kg                                                                                                                                                                                                               | Reference vehicle empty weight in kg for lost payload capacity opportunity cost calculation                                                                                                                                                                                                                                                                                                    | float                 |
| activate_tco_fueling_dwell_time_cost                                                                                                                                                                                                    | Boolean switch to activate fueling dwell time opportunity cost calculation                                                                                                                                                                                                                                                                                                                     | bool                  |
| downtime_oppy_cost_dol_per_hr                                                                                                                                                                                                                | Opportunity cost of dwell time for fueling vehicle as dollar per hour                                                                                                                                                                                                                                                                                                                          | float                 |
| fdt_num_free_dwell_trips                                                                                                                                                                                                                | Number of free trips or overnight charging opportunities that do not incur an opportunity cost penalty                                                                                                                                                                                                                                                                                         | float                 |
| fdt_dwpt_fraction_power_pct                                                                                                                                                                                                             | Fraction of vehicle power consumption through dynamic wireless power transfer                                                                                                                                                                                                                                                                                                                  | float                 |
| fdt_available_freetime_hr                                                                                                                                                                                                               | Number of hours of dwell time that do not incur opportunity cost penalty (eg., charging vehicle during scheduled lunch stops)                                                                                                                                                                                                                                                                  | float                 |
| fdt_avg_overhead_hr_per_dwell_hr                                                                                                                                                                                                        | Number of hours of overhead time during fueling/charging (eg., detour to gas station, time taken for plugging in charger, etc.)                                                                                                                                                                                                                                                                | float                 |
| fdt_frac_full_charge_bounds                                                                                                                                                                                                             | Lower and Upper bounds for fractional charge as a list [<lower>, <upper>]. <lower> is lowest fraction of charge/tank for a fractional charge at a fueling stop. <upper> is the highest fraction of charge/tank capacity above which it is preferred to rather fill up the batter/tank                                                                                                          | list\[float\]                  |
| activate_mr_downtime_cost                                                                                                                                                                                                               | Boolean switch to activate maintenance and repair (M&R) downtime opportunity cost calculation                                                                                                                                                                                                                                                                                                  | bool                  |
| mr_planned_downtime_hr_per_yr                                                                                                                                                                                                           | Regular/planned maintenance time in hours per year                                                                                                                                                                                                                                                                                                                                             | float                 |
| mr_unplanned_downtime_hr_per_mi                                                                                                                                                                                                         | Unplanned maintenance time per mile traveled as a vector with length equal to number of TCO years                                                                                                                                                                                                                                                                                              | list\[float\]                  |
| mr_tire_replace_downtime_hr_per_event                                                                                                                                                                                                   | Downtime hours per tire replacement event                                                                                                                                                                                                                                                                                                                                                      | float                 |
| mr_avg_tire_life_mi                                                                                                                                                                                                                     | Average life of tire in miles after which a tire replacement event takes place                                                                                                                                                                                                                                                                                                                 | float                 |
| insurance_rates_pct_per_yr                                                                                                                                                                                                              | Insurance rates as a percent of MSRP per year as vector with length equal to number of TCO years                                                                                                                                                                                                                                                                                               | list\[float\]                  |
